'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

/**
 * Handler functions
 */
var handlers = {
  handleDate: function handleDate(date) {
    // Handle Date
    var copy = new Date();
    copy.setTime(date.getTime());
    return copy;
  },
  handleArray: function handleArray(array) {
    var length = array.length;

    // Init array

    var copy = array.constructor(length);

    for (var i = 0; i < length; i++) {
      copy[i] = clone(array[i]);
    }

    return copy;
  },
  handleObject: function handleObject(object) {
    // Also copy prototypes
    var copy = Object.create(Object.getPrototypeOf(object));

    for (var attr in object) {
      if (object.hasOwnProperty(attr)) {
        copy[attr] = clone(object[attr]);
      }
    }
    return copy;
  },
  handle: function handle(object) {
    if (object instanceof Date) {
      return this.handleDate(object);
    } else if (object instanceof Array) {
      return this.handleArray(object);
    } else {
      return this.handleObject(object);
    }
  }
};

/**
 * Original StackOverflow answer https://stackoverflow.com/a/728694/6880789
 * This function will return cloned value
 * It can handle primitive data-type, Date, Array and Object
 * @param {null|undefined|number|string|function|object} object - any type
 * @return {null|undefined|number|string|function|object} - any type
 */
function clone(object) {
  // Handle primitive data-types, null and undefined
  if ((typeof object === 'undefined' ? 'undefined' : _typeof(object)) !== 'object' || object === null || typeof object === 'function') {
    return object;
  }
  return handlers.handle(object);
}

exports.default = clone;