"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

exports.default = curry;

/*
 * Original Source: https://stackoverflow.com/a/14045565/6121634
 * Updated to ES6 format to meet style guides via:
 * https://github.com/getify/Functional-Light-JS/blob/master/manuscript/ch3.md/#some-now-some-later
 *
 * This utility function takes a function as a parameter and returns a curried version of the function.
 *
 * @param {Function} func - The function to be curried
 * @return {Function} - The curried version of the initially provided function
 */

function curry(fn) {
  var arity = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : fn.length;

  return function nextCurried(prevArgs) {
    return function curried(nextArg) {
      var args = [].concat(_toConsumableArray(prevArgs), [nextArg]);

      if (args.length >= arity) {
        return fn.apply(undefined, _toConsumableArray(args));
      } else {
        return nextCurried(args);
      }
    };
  }([]);
}