'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = generatePassword;

/**
 * Original source: https://stackoverflow.com/questions/12635652/generate-a-secure-password-in-javascript
 * This function would generate a password
 * it is a modified copy
 * @param {int}len - The minimum length of the returned password
 * @param {int}capitals - The number of characters which must be capitalised
 * @param {int}lowercases - The number of characters which must be lowercase
 * @param {int}specials - the number of characters which must be special characters
 * @param {int}digits - The number of characters which must be digits
 * @return {string} - The randomised password
**/

function generatePassword() {
  var len = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 8;
  var capitals = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 1;
  var lowercases = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 1;
  var specials = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 1;
  var digits = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : 1;

  var password = '';
  var specialChars = '!@#$%^&*()_+{}:"<>?\\|[];\',./`~';
  var lowercaseChars = 'abcdefghijklmnopqrstuvwxyz';
  var uppercaseChars = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ';
  var digitChars = '0123456789';

  var allChars = specialChars + lowercaseChars + uppercaseChars + digitChars;

  password += pick(specialChars, specials);
  password += pick(lowercaseChars, lowercases);
  password += pick(uppercaseChars, capitals);
  password += pick(digitChars, digits);
  password += pick(allChars, Math.max(len - capitals - lowercases - specials - digits, 0));
  password = shuffle(password);

  return password;
}

function pick(characterList, count) {
  var chars = '';
  for (var i = 0; i < count; i++) {
    chars += characterList.charAt(Math.floor(Math.random() * characterList.length));
  }

  return chars;
}

// Credit to @Christoph: http://stackoverflow.com/a/962890/464744
function shuffle(str) {
  var array = str.split('');
  var tmp = void 0,
      current = void 0;
  var top = array.length;

  if (top) {
    while (--top) {
      current = Math.floor(Math.random() * (top + 1));
      tmp = array[current];
      array[current] = array[top];
      array[top] = tmp;
    }
  }

  return array.join('');
}