"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = range;

/**
 * @module range
 * @description This method creates an array of numbers (positive and/or
 * negative) progressing from start up to, but not including, end.
 *
 * @param {Number} start - The start of the range
 * @param {Number} end - The end of the range
 * @param {Number} step - The value to increment or decrement by
 * @return {Array} - Returns an array of integers containing an arithmetic
 * progression
 * */

function range() {
  var start = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
  var end = arguments[1];
  var step = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 1;

  if (end === undefined) {
    end = start;
    start = 0;
  }

  var length = Math.max(Math.ceil((end - start) / step), 0);
  var rangeArr = Array(length);

  for (var idx = 0; idx < length; idx++, start += step) {
    rangeArr[idx] = start;
  }

  return rangeArr;
}