'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

exports.default = shallowEqual;


function haveEqualKeys(a, b) {
  var keysA = Object.keys(a);
  var keysB = Object.keys(b);
  return keysA.length === keysB.length;
}

function isNullOrNonObject(obj) {
  return (typeof obj === 'undefined' ? 'undefined' : _typeof(obj)) !== 'object' || obj === null;
}

function compareKeys(objA, objB) {
  var keysA = Object.keys(objA);
  var bHasOwnProperty = Object.prototype.hasOwnProperty.bind(objB);
  for (var i = 0; i < keysA.length; i++) {
    if (!bHasOwnProperty(keysA[i]) || objA[keysA[i]] !== objB[keysA[i]]) {
      return false;
    }
  }

  return true;
}

/**
 * This method will shallow compare two objects
 *
 * @param {Object} objA - first object to compare
 * @param {Object} objB - second object to compare
 * @returns {boolean} - result of comparison - true if objects are shallow equal
 */

function shallowEqual(objA, objB) {
  if (objA === objB) {
    return true;
  }

  if (isNullOrNonObject(objA) || isNullOrNonObject(objB) || !haveEqualKeys(objA, objB)) {
    return false;
  }

  return compareKeys(objA, objB);
}