'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = textJustification;

/**
 *
 * Original Source: https://www.malikbrowne.com/blog/text-justification-coding-question
 *
 * Description: Given an array of words(input) and a length L, format the text such that each
 *              line has exactly L characters and is fully (left and right) justified.
 *
 * @param {Array} input - String array to be justified
 * @param {Integer} L - Length of characters per line
 * @return {Array} output - The string fully justified
 */

function textJustification(input, L) {
  var index = 0;
  var output = [];

  while (index < input.length) {

    var count = input[index].length;
    var last = index + 1;

    while (last < input.length) {

      if (input[last].length + count + 1 > L) {
        break;
      }
      count += input[last].length + 1;
      last++;
    }

    var line = '';
    var diff = last - index - 1;

    if (last === input.length || diff === 0) {

      for (var i = index; i < last; i++) {

        line += input[i] + ' ';
      }

      line = line.substr(0, line.length - 1);

      for (var _i = line.length; _i < L; _i++) {
        line += ' ';
      }
    } else {

      var space = (L - count) / diff;
      var remainder = (L - count) % diff;

      for (var _i2 = index; _i2 < last; _i2++) {
        line += input[_i2];

        if (_i2 < last - 1) {

          var max = space + (_i2 - index < remainder ? 1 : 0);

          for (var j = 0; j <= max; j++) {
            line += ' ';
          }
        }
      }
    }

    output.push(line);
    index = last;
  }
  return output;
}

/* eslint complexity: "off", max-depth: "off" */